| Title: | Small Example Response and Response Time Data from PISA 2018 |
|---|---|
| Description: | Scored responses and responses times from the Canadian subsample of the PISA 2018 assessment, accessible as the "Cognitive items total time/visits data file" by OECD (2020) <https://www.oecd.org/pisa/data/2018database/>. |
| Authors: | Benjamin Becker [aut, cre], Esther Ulitzsch [ctb], Christoph Koenig [ctb] |
| Maintainer: | Benjamin Becker <[email protected]> |
| License: | CC BY 4.0 |
| Version: | 2.0.2 |
| Built: | 2026-05-16 06:29:28 UTC |
| Source: | https://github.com/cran/pisaRT |
A small example data set from the Canadian sample of the PISA 2018 assessment. Contains responses, response times
and log transformed response times of a single math booklet.
This data set is in the long format, with each row containing the scored response and response time of a person on a single item. For
further explanations see pisaRT.
pisaLpisaL
A data.frame with 6000 rows and 5 variables:
Person ID variable
Item number
Scored responses
Response time in seconds
Log Response time
https://www.oecd.org/pisa/data/2018database/
A small example data set from the Canadian sample of the PISA 2018 assessment. Contains responses, response times
and log transformed response times of a single math booklet.
This data set is in the wide format, with each row containing the scored responses and response times of a person on all booklet items. For
further explanations see pisaRT.
pisaWpisaW
A data.frame with 500 rows and 37 variables:
Person ID variable
Scored responses on item x
Response time in seconds on item x
Log Response time on item x
https://www.oecd.org/pisa/data/2018database/